ged4py package
==============

Subpackages
-----------

.. toctree::

   ged4py.detail

Submodules
----------

.. toctree::

   ged4py.model
   ged4py.parser

Module contents
---------------

.. automodule:: ged4py
   :members:
   :undoc-members:
   :show-inheritance:
